==> shortcuts-1.0.0.tgz: package/test/modules/shortcut.js <==

const Consts = require ( '../../dist/consts' ).default;
const {Shortcut} = require ( '../../dist' );

describe ( 'Shortcut', () => {

  describe ( 'getTriggerKey', it => {

    it ( 'gets the trigger key', t => {

      const map = {
        'A': 'A' ,
        'Ctrl+A': 'A',
        'F5': 'F5',
        'F50': '',
        'Foo': '',
        '∂': ''
      };

      Object.entries ( map ).map ( ([ shortcut, triggerKey ]) => {

        t.is ( Shortcut.id2accelerator ([ Shortcut.getTriggerKey ( Shortcut.chord2id ( shortcut ) ) ]), triggerKey );

      });

    });

  });

  describe ( 'isValid', it => {

    it ( 'checks if a shortcut id is valid', t => {

      const map = {
        'A': true ,
        'Ctrl+A': true,
        'F5': true,
        'F50': false,
        'Foo': false
      };

      Object.entries ( map ).map ( ([ shortcut, isValid ]) => {

        t.is ( Shortcut.isValidID ( Shortcut.shortcut2id ( shortcut ) ), isValid, Shortcut.shortcut2id ( shortcut ) );

      });

    });

  });

  describe ( 'shortcut2accelerator', it => {

    it ( 'supports basic single-key shortcuts', t => {

      Object.values ( Consts.key2id ).forEach ( id => {

        const shortcut = Consts.id2accelerator[id];

        t.is ( Shortcut.shortcut2accelerator ( shortcut ), shortcut );

      });

    });

    it ( 'supports basic multi-key shortcuts', t => {

      Object.values ( Consts.key2id ).forEach ( id => {

        if ( !Shortcut.getTriggerKey ( id ) ) return;

        const shortcut = `Ctrl+${Consts.id2accelerator[id]}`;

        t.is ( Shortcut.shortcut2accelerator ( shortcut ), shortcut );

      });

    });

    it ( 'supports basic chord shortcuts', t => {

      Object.values ( Consts.key2id ).forEach ( id => {

        const shortcutSingle = `Ctrl+K ${Consts.id2accelerator[id]}`;

        t.is ( Shortcut.shortcut2accelerator ( shortcutSingle ), shortcutSingle );

        if ( Shortcut.getTriggerKey ( id ) ) {

          const shortcutMulti = `Ctrl+K Ctrl+${Consts.id2accelerator[id]}`;

          t.is ( Shortcut.shortcut2accelerator ( shortcutMulti ), shortcutMulti );

        }

      });

    });

    it ( 'supports advanced shortcuts', t => {

      const tests = [
        ['A', 'A'],
        ['a', 'A'],
        ['Meta', 'Cmd'],
        ['Ctrl+Alt+Shift+Cmd+A', 'Ctrl+Alt+Shift+Cmd+A'],
        ['Alt+Ctrl+Command+Alt+Shift+Cmd+A', 'Ctrl+Alt+Shift+Cmd+A'],
        ['Option+Control+Command', 'Ctrl+Alt+Cmd'],
        ['Ctrl++', 'Ctrl+Plus'],
        ['Ctrl+K Alt+D', 'Ctrl+K Alt+D'],
        ['Ctrl+K Shift+Numpad0', 'Ctrl+K Shift+Numpad0'],
        ['Ctrl+K Ctrl+K', 'Ctrl+K Ctrl+K']
      ];

      tests.forEach ( ([ shortcut, output ]) => {

        t.is ( Shortcut.shortcut2accelerator ( shortcut ), output );

      });

    });

  });

  describe ( 'shortcut2symbols', it => {

    it ( 'converts ids to symbols', t => {

      const tests = [
        ['A', 'A'],
        ['a', 'A'],
        ['Ctrl+Alt+Shift+Cmd+A', '⌃⌥⇧⌘A'],
        ['Alt+Ctrl+Command+Alt+Shift+Cmd+A', '⌃⌥⇧⌘A'],
        ['Ctrl++', '⌃+'],
      ];

      tests.forEach ( ([ shortcut, output ]) => {

        t.is ( Shortcut.shortcut2symbols ( shortcut ), output );

      });

    });

  });

});

==> shortcuts-1.7.0.tgz: package/test/modules/shortcut.js <==

const Consts = require ( '../../dist/consts' ).default;
const {Shortcut} = require ( '../../dist' );

describe ( 'Shortcut', () => {

  describe ( 'getTriggerKey', it => {

    it ( 'gets the trigger key', t => {

      const map = {
        'A': 'A' ,
        'Ctrl+A': 'A',
        'F5': 'F5',
        'F50': '',
        'Foo': '',
        '∂': ''
      };

      Object.entries ( map ).map ( ([ shortcut, triggerKey ]) => {

        t.is ( Shortcut.id2accelerator ([ Shortcut.getTriggerKey ( Shortcut.chord2id ( shortcut ) ) ]), triggerKey );

      });

    });

  });

  describe ( 'isValid', it => {

    it ( 'checks if a shortcut id is valid', t => {

      const map = {
        'A': true ,
        'Ctrl+A': true,
        'F5': true,
        'F50': false,
        'Foo': false
      };

      Object.entries ( map ).map ( ([ shortcut, isValid ]) => {

        t.is ( Shortcut.isValidID ( Shortcut.shortcut2id ( shortcut ) ), isValid, Shortcut.shortcut2id ( shortcut ) );

      });

    });

  });

  describe ( 'shortcut2accelerator', it => {

    it ( 'supports basic single-key shortcuts', t => {

      Object.entries ( Consts.id2shortcut ).forEach ( ([ id, shortcut ]) => {

        t.is ( Shortcut.shortcut2accelerator ( shortcut ), Consts.id2accelerator[id] );

      });

    });

    it ( 'supports basic multi-key shortcuts', t => {

      Object.entries ( Consts.id2accelerator ).forEach ( ([ id, accelerator ]) => {

        if ( !Shortcut.getTriggerKey ( id ) ) return;

        const shortcut = `Ctrl+${Consts.id2shortcut[id]}`;

        t.is ( Shortcut.shortcut2accelerator ( shortcut ), `Ctrl+${accelerator}` );

      });

    });

    it ( 'supports basic chord shortcuts', t => {

      Object.entries ( Consts.id2accelerator ).forEach ( ([ id, accelerator ]) => {

        const shortcutSingle = `Ctrl+K ${Consts.id2shortcut[id]}`;

        t.is ( Shortcut.shortcut2accelerator ( shortcutSingle ), `Ctrl+K ${accelerator}` );

        if ( Shortcut.getTriggerKey ( id ) ) {

          const shortcutMulti = `Ctrl+K Ctrl+${Consts.id2shortcut[id]}`;

          t.is ( Shortcut.shortcut2accelerator ( shortcutMulti ), `Ctrl+K Ctrl+${accelerator}` );

        }

      });

    });

    it ( 'supports advanced shortcuts', t => {

      const tests = [
        ['A', 'A'],
        ['a', 'A'],
        ['Meta', 'Cmd'],
        ['Ctrl+Alt+Shift+Cmd+A', 'Ctrl+Alt+Shift+Cmd+A'],
        ['Alt+Ctrl+Command+Alt+Shift+Cmd+A', 'Ctrl+Alt+Shift+Cmd+A'],
        ['Option+Control+Command', 'Ctrl+Alt+Cmd'],
        ['Ctrl++', 'Ctrl+Plus'],
        ['Ctrl+K Alt+D', 'Ctrl+K Alt+D'],
        ['Ctrl+K Shift+Numpad0', 'Ctrl+K Shift+num0'],
        ['Ctrl+K Ctrl+K', 'Ctrl+K Ctrl+K']
      ];

      tests.forEach ( ([ shortcut, output ]) => {

        t.is ( Shortcut.shortcut2accelerator ( shortcut ), output );

      });

    });

  });

  describe ( 'shortcut2symbols', it => {

    it ( 'converts ids to symbols', t => {

      const tests = [
        ['A', 'A'],
        ['a', 'A'],
        ['Ctrl+Alt+Shift+Cmd+A', '⌃⌥⇧⌘A'],
        ['Alt+Ctrl+Command+Alt+Shift+Cmd+A', '⌃⌥⇧⌘A'],
        ['Ctrl++', '⌃+'],
      ];

      tests.forEach ( ([ shortcut, output ]) => {

        t.is ( Shortcut.shortcut2symbols ( shortcut ), output );

      });

    });

  });

});
